( cd opt/kde/share/doc/HTML/da/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ark ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kig ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/juk ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktuberling ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/amor ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/karm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kate ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdat ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdvi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kgeo ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kgeo ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kget ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kgpg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmag ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmid ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmix ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kodo ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kolf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpat ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpdf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/korn ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kppp ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/krdc ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/krdc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/krec ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/krfb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kscd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksim ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/lisa ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kxkb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kalzium ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/katomic ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksysguard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbounce ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdearch ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdearch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbattleship ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kaboodle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/knewsticker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khangman ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kfloppy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/cervisia ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khexedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpercentage ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kandy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcalc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdesu ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcron ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdict ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kfind ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kiten ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kjots ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmail ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmoon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/knode ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kooka ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksame ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksirc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktnef ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktnef ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksysv ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktron ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kuser ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kview ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwin4 ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/lskat ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klipper ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmousetool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kompare ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kontact ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/konsole ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpackage ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kshisen ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksirtet ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/konquest ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kturtle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kverbos ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwallet ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kweather ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwuftpd ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kioslave ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/flashkard ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/flashkard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kxconfig ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/da/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/da/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/artsbuilder ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbabel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kalarm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kamera ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdeprint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kasteroids ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kbruch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/keduca ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kgamma ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdevelop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kicker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klatin ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klatin ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmouth ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmplot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/knotes ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpaint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kopete ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpilot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpoker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kruler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktalkd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksnake ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kspell ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kstars ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktimer ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ktouch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwrite ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/megami ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kreversi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/noatun ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksplashml ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kblackbox ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kcharselect ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/quanta ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kuickshow ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kolourpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kommander ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kiconedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klettres ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kghostview ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/klickety ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kleopatra ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kenolaba ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwatchgnupg ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kworldclock ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/ksokoban ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kteatime ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kmathtool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/umbrello ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/konqueror ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/kwordquiz ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/korganizer ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/da/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/atlantik ; ln -sf /opt/kde/share/doc/HTML/da/common common )
